@@ -779,6 +779,22 @@ class Builder(Update):
             self._startEmerging(emerge)
         return True
 
+    def update_layman(self, builder_path):
+        """
+        Обновить базу layman
+        :param builder_path:
+        :return:
+        """
+        cmd = "/usr/bin/layman"
+        cmd_path = self.get_prog_path(cmd)
+        logfile = self._get_log_file()
+        if not cmd_path:
+            raise BuilderError(_("Failed to find the %s command") % cmd)
+        layman = self.chrootize(builder_path, CommandExecutor(cmd_path, ["-f"],
+                                                              logfile=logfile))
+        layman.execute()
+        return layman.success()
+
     def syncLaymanRepository(self, repname):
         """
         Обновить репозиторий через layman
