@@ -25,7 +25,7 @@ from ..datavars import BuilderError
 from os import path
 from calculate.lib.utils.git import GitError
 from calculate.lib.utils.portage import (EmergeLogNamedTask,
-                                         PackageList, EmergeLog)
+                                         PackageList, EmergeLog, isPkgInstalled)
 from calculate.install.distr import DistributiveError
 from calculate.update.update_tasks import EmergeMark
 
@@ -152,6 +152,13 @@ class ClBuilderUpdateAction(Action):
                       'condition': lambda Get: Get(
                           'cl_builder_binary_set') == "on"
                       },
+                     {'name': 'update_layman',
+                      'message': __("Updating layman cache"),
+                      'method': "Builder.update_layman(cl_builder_path)",
+                      'condition': lambda Get: isPkgInstalled(
+                          "app-portage/layman", prefix=Get('cl_chroot_path')),
+                      'essential': False,
+                      },
                      {'name': 'sync_other_reps',
                       'foreach': 'builder.cl_builder_other_rep_name',
                       'message': __(
