@@ -238,7 +238,7 @@ class VariableClBuilderDiskDev(Variable):
     metavalue = "DEST"
 
     def init(self):
-        self.label = _("Build location")
+        self.label = _("Build files")
         self.help = _("partition or directory intended for build")
 
     def get_builder_image_dn(self, ds=None):
@@ -1219,6 +1219,7 @@ class VariableClBuilderCompress(Variable):
     opt = ["-c", "--compress"]
     metavalue = "COMPRESS"
     untrusted = True
+    check_after = ["cl_builder_id"]
 
     def init(self):
         self.label = _("Compressor")
@@ -1648,9 +1649,9 @@ class VariableClBuilderEixRepositories(ReadonlyVariable):
 
     def get(self):
         return ", ".join(
-            x.capitalize() for x in chain(
-                reversed(self.Get('update.cl_update_rep_name')),
-                self.Get('builder.cl_builder_other_rep_name')))
+            x.capitalize() for x in reversed(list(chain(
+                self.Get('update.cl_update_rep_name'),
+                self.Get('builder.cl_builder_other_rep_name')))))
 
 
 class VariableClBuilderBinhostStableSet(
@@ -1684,3 +1685,30 @@ class VariableClBuilderBinhostScanSet(Variable):
     Сканировать или нет зеркала (переменная переключается во время действия)
     """
     value = "off"
+
+
+class VariableClBuilderCheckAutomagicSet(Variable):
+    """
+    Выполнить проверку на наличие неописанных автоматических зависимостей
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["--check-autodep"]
+
+    def init(self):
+        self.label = _("Check for auto depends")
+        self.help = _("check for auto depends")
+
+class VariableClBuilderCleanBdepsSet(Variable):
+    """
+    Отключить --with-bdeps при выполнении --depclean
+    """
+    type = "bool"
+    value = "off"
+
+    opt = ["--clean-bdeps"]
+
+    def init(self):
+        self.label = _("Remove packages required only for build")
+        self.help = _("remove packages required only for build")
